==> haskell-shell-escape-0.2.0-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shell-escape.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 shell-escape
version:              0.2.0
visibility:           public
id:                   shell-escape-0.2.0-3Qh6bWSSJiHLYReqxPHJce
key:                  shell-escape-0.2.0-3Qh6bWSSJiHLYReqxPHJce
license:              BSD-3-Clause
maintainer:           oss@solidsnack.be
author:               Jason Dusek
homepage:             http://github.com/solidsnack/shell-escape
synopsis:             Shell escaping library.
description:
    Shell escaping library, offering both Bourne shell and Bash style escaping
    of ByteStrings.

category:             Text
abi:                  f76295c1d4408829778f5641b8ab2aa2
exposed:              True
exposed-modules:      Data.ByteString.ShellEscape Text.ShellEscape
hidden-modules:
    Data.ByteString.ShellEscape.Escape
    Data.ByteString.ShellEscape.EscapeVector
    Data.ByteString.ShellEscape.Sh Data.ByteString.ShellEscape.Bash
    Data.ByteString.ShellEscape.Put

import-dirs:          /usr/lib/ghc-9.0.1/site-local/shell-escape-0.2.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/shell-escape-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/shell-escape-0.2.0
hs-libraries:         HSshell-escape-0.2.0-3Qh6bWSSJiHLYReqxPHJce
depends:
    base-4.15.0.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 vector-0.12.3.1-EtdN61cdG6Y4MwC0gVwGz6

haddock-interfaces:
    /usr/share/doc/haskell-shell-escape/html/shell-escape.haddock

haddock-html:         /usr/share/doc/haskell-shell-escape/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shell-escape-0.2.0-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shell-escape.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 shell-escape
version:              0.2.0
visibility:           public
id:                   shell-escape-0.2.0-5epkWbiOtrx7TBQLxy9tF3
key:                  shell-escape-0.2.0-5epkWbiOtrx7TBQLxy9tF3
license:              BSD-3-Clause
maintainer:           oss@solidsnack.be
author:               Jason Dusek
homepage:             http://github.com/solidsnack/shell-escape
synopsis:             Shell escaping library.
description:
    Shell escaping library, offering both Bourne shell and Bash style escaping
    of ByteStrings.

category:             Text
abi:                  cd7dac4e033915c4aaee967d834d2939
exposed:              True
exposed-modules:      Data.ByteString.ShellEscape Text.ShellEscape
hidden-modules:
    Data.ByteString.ShellEscape.Escape
    Data.ByteString.ShellEscape.EscapeVector
    Data.ByteString.ShellEscape.Sh Data.ByteString.ShellEscape.Bash
    Data.ByteString.ShellEscape.Put

import-dirs:          /usr/lib/ghc-9.0.2/site-local/shell-escape-0.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/shell-escape-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/shell-escape-0.2.0
hs-libraries:         HSshell-escape-0.2.0-5epkWbiOtrx7TBQLxy9tF3
depends:
    base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 vector-0.12.3.1-IPjkfAE3hEhDt08GLG1iXV

haddock-interfaces:
    /usr/share/doc/haskell-shell-escape/html/shell-escape.haddock

haddock-html:         /usr/share/doc/haskell-shell-escape/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
